pub struct OctoJob {
pub state: OctoJobState,
pub job: Option<OctoJobDetails>,
pub progress: Option<OctoProgress>,
}Fields
state: OctoJobStateThe printer state
job: Option<OctoJobDetails>The details of the job that is being processed if a job is being processed.
progress: Option<OctoProgress>The progress of the current print if there is one.